/// <reference types="node" />
import BigNumber from "bignumber.js";
import { Address } from "../core/address";
import { ArgumentErrorContext } from "./argumentErrorContext";
import { EndpointDefinition, EndpointParameterDefinition, TypedValue } from "./typesystem";
export declare namespace NativeTypes {
    type NativeBuffer = Buffer | string;
    type NativeBytes = Buffer | {
        valueOf(): Buffer;
    } | string;
    type NativeAddress = string | Buffer | Address | {
        getAddress(): Address;
    };
    type NativeBigNumber = BigNumber.Value | bigint;
}
export declare namespace NativeSerializer {
    /**
     * Interprets a set of native javascript values into a set of typed values, given parameter definitions.
     */
    function nativeToTypedValues(args: any[], endpoint: EndpointDefinition): TypedValue[];
    function getArgumentsCardinality(parameters: EndpointParameterDefinition[]): {
        min: number;
        max: number;
        variadic: boolean;
    };
    function convertNativeToAddress(native: NativeTypes.NativeAddress, errorContext: ArgumentErrorContext): Address;
}
