import { Address } from "../core/address";
import { Transaction } from "../core/transaction";
import { ContractFunction } from "./function";
import { Interaction } from "./interaction";
import { CallArguments, DeployArguments, ISmartContract, QueryArguments, UpgradeArguments } from "./interface";
import { Query } from "./query";
import { Abi, EndpointDefinition, TypedValue } from "./typesystem";
/**
 * * @deprecated component. Use "SmartContractTransactionsFactory" or "SmartContractController", instead.
 *
 * An abstraction for deploying and interacting with Smart Contracts.
 */
export declare class SmartContract implements ISmartContract {
    private address;
    private abi?;
    /**
     * This object contains a function for each endpoint defined by the contract.
     * (a bit similar to web3js's "contract.methods").
     */
    readonly methodsExplicit: {
        [key: string]: (args?: TypedValue[]) => Interaction;
    };
    /**
     * This object contains a function for each endpoint defined by the contract.
     * (a bit similar to web3js's "contract.methods").
     *
     * This is an alternative to {@link methodsExplicit}.
     * Unlike {@link methodsExplicit}, automatic type inference (wrt. ABI) is applied when using {@link methods}.
     */
    readonly methods: {
        [key: string]: (args?: any[]) => Interaction;
    };
    /**
     * Create a SmartContract object by providing its address on the Network.
     */
    constructor(options?: {
        address?: Address;
        abi?: Abi;
    });
    private setupMethods;
    /**
     * Sets the address, as on Network.
     */
    setAddress(address: Address): void;
    /**
     * Gets the address, as on Network.
     */
    getAddress(): Address;
    private getAbi;
    getEndpoint(name: string | ContractFunction): EndpointDefinition;
    /**
     * Creates a {@link Transaction} for deploying the Smart Contract to the Network.
     */
    deploy({ deployer, code, codeMetadata, initArguments, value, gasLimit, gasPrice, chainID, }: DeployArguments): Transaction;
    private getMetadataPropertiesAsObject;
    /**
     * Creates a {@link Transaction} for upgrading the Smart Contract on the Network.
     */
    upgrade({ caller, code, codeMetadata, initArguments, value, gasLimit, gasPrice, chainID, }: UpgradeArguments): Transaction;
    /**
     * Creates a {@link Transaction} for calling (a function of) the Smart Contract.
     */
    call({ func, args, value, gasLimit, receiver, gasPrice, chainID, caller }: CallArguments): Transaction;
    createQuery({ func, args, value, caller }: QueryArguments): Query;
    private ensureHasAddress;
    /**
     * Computes the address of a Smart Contract.
     * The address is computed deterministically, from the address of the owner and the nonce of the deployment transaction.
     *
     * @param owner The owner of the Smart Contract
     * @param nonce The owner nonce used for the deployment transaction
     */
    static computeAddress(owner: Address, nonce: bigint): Address;
}
