import BigNumber from "bignumber.js";
import { PrimitiveType, PrimitiveValue } from "./types";
export declare class NumericalType extends PrimitiveType {
    static ClassName: string;
    readonly sizeInBytes: number;
    readonly withSign: boolean;
    protected constructor(name: string, sizeInBytes: number, withSign: boolean);
    getClassName(): string;
    hasFixedSize(): boolean;
    hasArbitrarySize(): boolean;
}
export declare class U8Type extends NumericalType {
    static ClassName: string;
    constructor();
    getClassName(): string;
}
export declare class I8Type extends NumericalType {
    static ClassName: string;
    constructor();
    getClassName(): string;
}
export declare class U16Type extends NumericalType {
    static ClassName: string;
    constructor();
    getClassName(): string;
}
export declare class I16Type extends NumericalType {
    static ClassName: string;
    constructor();
    getClassName(): string;
}
export declare class U32Type extends NumericalType {
    static ClassName: string;
    constructor();
    getClassName(): string;
}
export declare class I32Type extends NumericalType {
    static ClassName: string;
    constructor();
    getClassName(): string;
}
export declare class U64Type extends NumericalType {
    static ClassName: string;
    constructor();
    getClassName(): string;
}
export declare class I64Type extends NumericalType {
    static ClassName: string;
    constructor();
    getClassName(): string;
}
export declare class BigUIntType extends NumericalType {
    static ClassName: string;
    constructor();
    getClassName(): string;
}
export declare class BigIntType extends NumericalType {
    static ClassName: string;
    constructor();
    getClassName(): string;
}
/**
 * A numerical value fed to or fetched from a Smart Contract contract, as a strongly-typed, immutable abstraction.
 */
export declare class NumericalValue extends PrimitiveValue {
    static ClassName: string;
    readonly value: BigNumber;
    readonly sizeInBytes: number | undefined;
    readonly withSign: boolean;
    constructor(type: NumericalType, value: BigNumber.Value | bigint);
    getClassName(): string;
    /**
     * Returns whether two objects have the same value.
     *
     * @param other another NumericalValue
     */
    equals(other: NumericalValue): boolean;
    valueOf(): BigNumber;
    toString(): string;
}
export declare class U8Value extends NumericalValue {
    static ClassName: string;
    constructor(value: BigNumber.Value | bigint);
    getClassName(): string;
}
export declare class I8Value extends NumericalValue {
    static ClassName: string;
    constructor(value: BigNumber.Value | bigint);
    getClassName(): string;
}
export declare class U16Value extends NumericalValue {
    static ClassName: string;
    constructor(value: BigNumber.Value | bigint);
    getClassName(): string;
}
export declare class I16Value extends NumericalValue {
    static ClassName: string;
    constructor(value: BigNumber.Value | bigint);
    getClassName(): string;
}
export declare class U32Value extends NumericalValue {
    static ClassName: string;
    constructor(value: BigNumber.Value | bigint);
    getClassName(): string;
}
export declare class I32Value extends NumericalValue {
    static ClassName: string;
    constructor(value: BigNumber.Value | bigint);
    getClassName(): string;
}
export declare class U64Value extends NumericalValue {
    static ClassName: string;
    constructor(value: BigNumber.Value | bigint);
    getClassName(): string;
}
export declare class I64Value extends NumericalValue {
    static ClassName: string;
    constructor(value: BigNumber.Value | bigint);
    getClassName(): string;
}
export declare class BigUIntValue extends NumericalValue {
    static ClassName: string;
    constructor(value: BigNumber.Value | bigint);
    getClassName(): string;
}
export declare class BigIntValue extends NumericalValue {
    static ClassName: string;
    constructor(value: BigNumber.Value | bigint);
    getClassName(): string;
}
