"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BaseController = void 0;
const constants_1 = require("./constants");
const transactionComputer_1 = require("./transactionComputer");
class BaseController {
    setTransactionGasOptions(transaction, options) {
        if (options.gasLimit) {
            transaction.gasLimit = options.gasLimit;
        }
        else {
            this.addExtraGasLimitIfRequired(transaction);
        }
        if (options.gasPrice) {
            transaction.gasPrice = options.gasPrice;
        }
    }
    addExtraGasLimitIfRequired(transaction) {
        if (transaction.guardian && !transaction.guardian.isEmpty()) {
            transaction.gasLimit += BigInt(constants_1.EXTRA_GAS_LIMIT_FOR_GUARDED_TRANSACTIONS);
        }
        if (transaction.relayer && !transaction.relayer.isEmpty()) {
            transaction.gasLimit += BigInt(constants_1.EXTRA_GAS_LIMIT_FOR_RELAYED_TRANSACTIONS);
        }
    }
    setVersionAndOptionsForGuardian(transaction) {
        if (transaction.guardian && !transaction.guardian.isEmpty()) {
            const txComputer = new transactionComputer_1.TransactionComputer();
            txComputer.applyGuardian(transaction, transaction.guardian);
        }
    }
}
exports.BaseController = BaseController;
//# sourceMappingURL=baseController.js.map