"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DelegationTransactionsOutcomeParser = void 0;
const address_1 = require("../core/address");
const errors_1 = require("../core/errors");
const resources_1 = require("../transactionsOutcomeParsers/resources");
class DelegationTransactionsOutcomeParser {
    constructor() { }
    parseCreateNewDelegationContract(transaction) {
        this.ensureNoError(transaction.logs.events);
        const events = resources_1.findEventsByIdentifier(transaction, "SCDeploy");
        return events.map((event) => ({ contractAddress: this.extractContractAddress(event) }));
    }
    ensureNoError(transactionEvents) {
        for (const event of transactionEvents) {
            if (event.identifier == "signalError") {
                const data = Buffer.from(event.additionalData[0]?.toString().slice(1)).toString() || "";
                const message = this.decodeTopicAsString(event.topics[1]);
                throw new errors_1.ErrParseTransactionOutcome(`encountered signalError: ${message} (${Buffer.from(data, "hex").toString()})`);
            }
        }
    }
    extractContractAddress(event) {
        if (!event.topics[0]?.length) {
            return "";
        }
        const address = Buffer.from(event.topics[0]);
        return new address_1.Address(address).toBech32();
    }
    decodeTopicAsString(topic) {
        return Buffer.from(topic).toString();
    }
}
exports.DelegationTransactionsOutcomeParser = DelegationTransactionsOutcomeParser;
//# sourceMappingURL=delegationTransactionsOutcomeParser.js.map