import { Abi } from "../abi";
import { Address, TransactionOnNetwork } from "../core";
import { SmartContractDeployOutcome } from "../smartContracts/resources";
/**
 * Parses the outcome of multisig contract operations
 */
export declare class MultisigTransactionsOutcomeParser {
    private parser;
    private readonly abi;
    constructor(options: {
        abi: Abi;
    });
    /**
     * Parses the outcome of creating a new multisig contract
     * @param transactionOnNetwork The completed transaction
     * @returns An array of objects containing the new contract addresses
     */
    parseDeploy(transactionOnNetwork: TransactionOnNetwork): SmartContractDeployOutcome;
    /**
     * Parses the outcome of a multisig action proposal
     * @param transactionOnNetwork The completed transaction
     * @returns The action ID that was created
     */
    parseProposeAction(transactionOnNetwork: TransactionOnNetwork): number;
    /**
     * Parses the outcome of a multisig action proposal
     * @param transactionOnNetwork The completed transaction
     * @returns In case of scDeploy returns address else undefined
     */
    parsePerformAction(transactionOnNetwork: TransactionOnNetwork): Address | undefined;
}
