/**
 * An object holding Network configuration parameters.
 */
export declare class NetworkConfig {
    raw: Record<string, any>;
    /**
     * The chain ID. E.g. "1" for the Mainnet.
     */
    chainID: string;
    /**
     * The gas required by the Network to process a byte of the transaction data.
     */
    gasPerDataByte: bigint;
    gasPriceModifier: number;
    /**
     * The minimum gas limit required to be set when broadcasting a transaction.
     */
    minGasLimit: bigint;
    /**
     * The minimum gas price required to be set when broadcasting a transaction.
     */
    minGasPrice: bigint;
    /**
     * The extra gas needed for guarded transactions.
     */
    extraGasLimitForGuardedTransactions: bigint;
    /**
     * The number of shards.
     */
    numShards: number;
    /**
     * The round duration.
     */
    roundDuration: number;
    /**
     * The number of rounds per epoch.
     */
    numRoundsPerEpoch: number;
    /**
     * The genesis timestamp
     */
    genesisTimestamp: number;
    constructor();
    /**
     * Constructs a configuration object from a HTTP response (as returned by the provider).
     */
    static fromHttpResponse(payload: any): NetworkConfig;
}
