"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.KeyPair = void 0;
const userKeys_1 = require("./userKeys");
class KeyPair {
    constructor(secretKey) {
        this.secretKey = secretKey;
        this.publicKey = this.secretKey.generatePublicKey();
    }
    static generate() {
        const secretKey = userKeys_1.UserSecretKey.generate();
        return new KeyPair(secretKey);
    }
    static newFromBytes(data) {
        const secretKey = new userKeys_1.UserSecretKey(data);
        return new KeyPair(secretKey);
    }
    async sign(data) {
        return this.secretKey.sign(data);
    }
    async verify(data, signature) {
        return this.publicKey.verify(data, signature);
    }
    getSecretKey() {
        return this.secretKey;
    }
    getPublicKey() {
        return this.publicKey;
    }
}
exports.KeyPair = KeyPair;
//# sourceMappingURL=keypair.js.map